@@ -46,7 +46,7 @@ struct Pg_dir_state => {
 };
 
 use constant {
-    VERSIONNUM       => "10.0",
+    VERSIONNUM       => "10.1",
     VERSIONINFO      => "[0] (pg-rex_operation_tools) [1]\n",
     CONFIG_PATH      => "/etc/",
     CONFIG_FILENAME  => "pg-rex_tools.conf",
@@ -178,8 +178,10 @@ sub network_running{
         
         # crm_attribute の実行結果が "<IPアドレス> is UP"であれば、corosync.conf の設定と
         # IPアドレスが一致しているかを確認する
+        # なお、crm_attribute の実行結果から取得できるIPアドレスのため、
+        # 厳密なIPv4の正規表現でIPアドレスを取得しない
         if ($result =~ /^(\d+\.\d+\.\d+\.\d+)\sis\sUP/){
-            @matched = grep {/$1/} @{$$iclan_ipaddr{'my_node'}};
+            @matched = grep {$_ eq $1} @{$$iclan_ipaddr{'my_node'}};
             if (@matched == 0){
                 return 0;
             }
@@ -199,8 +201,10 @@ sub network_running{
         
         # crm_attribute の実行結果が "<IPアドレス> is UP"であれば、corosync.conf の設定と
         # IPアドレスが一致しているかを確認する
+        # なお、crm_attribute の実行結果から取得できるIPアドレスのため、
+        # 厳密なIPv4の正規表現でIPアドレスを取得しない
         if ($result =~ /^(\d+\.\d+\.\d+\.\d+)\sis\sUP/){
-            @matched = grep {/$1/} @{$$iclan_ipaddr{'another_node'}};
+            @matched = grep {$_ eq $1} @{$$iclan_ipaddr{'another_node'}};
             if (@matched == 0){
                 return 0;
             }
@@ -662,7 +666,7 @@ sub read_hacf{
         # comment format : #<comment>
         $line =~ s/\#.*//g;
         # format of bindnetaddr in corosync.conf: bindnetaddr: <network address> or <IP adress>
-        if ($line =~ /^\s*bindnetaddr:\s+(\S+)/){
+        if ($line =~ /^\s*bindnetaddr:\s+(\S+)(\s.*)?$/){
             push(@iclan_netaddr, $1);
         }
     }
@@ -725,6 +729,7 @@ sub get_iclan_ipaddr{
     my $nic;
     my %iclan_ipaddr;
     my $command;
+    my @record;
 
     # 自身のノードと相手先のノードの IC-LAN IP アドレスを取得する
     for (my $count = 0; $count < 2; $count++){
@@ -733,21 +738,26 @@ sub get_iclan_ipaddr{
             # bindnetaddr にホストアドレスが設定されていると判断し、ifconfig
             # コマンドで確認した上で bindnetaddrの設定値を IC-LAN IP アドレス
             # として取得する
-            $command = "$IFCONFIG | $GREP \"$netaddr\"";
+            $command = "$IFCONFIG | $GREP -F \" $netaddr \"";
             if ($count == 0){
                 $results[0] = `$command`;
             }
             else {
                 @results = ssh_exec_command($ssh_info, $command);
             }
-            if ($results[0] =~ /($netaddr)/){
-                push(@{$ipaddr_list{$site[$count]}}, $1);
-                next;
+            if ($results[0] =~ /inet\s(addr:)?([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)\s/) {
+                if ($2 eq $netaddr){
+                    if (!is_ipv4_format($2)){
+                        printlog("ERROR", COMMON_MS0052, $2);
+                    }
+                    push(@{$ipaddr_list{$site[$count]}}, $2);
+                    next;
+                }
             }
 
             # bindnetaddr にネットワークアドレスが設定されている場合は、当該アドレスが
             # 設定されている NIC を特定する
-            $command = "$ROUTE | $GREP \"$netaddr\"";
+            $command = "$ROUTE";
             if ($count == 0){
                 $results[0] = `$command`;
             }
@@ -758,8 +768,17 @@ sub get_iclan_ipaddr{
             if (!$results[0]){
                 printlog("ERROR", COMMON_MS0039, $node_list[$count], $netaddr);
             }
-            @field = split(/\s+/, $results[0]);
-            $nic = $field[7];
+
+            @record = split (/\n/, $results[0]);
+            foreach (@record) {
+                # routeのコマンドの実行結果はスペース区切りとなるため、
+                # スペースをデリミタとしてsplitする
+                # $element[0]にIPアドレス、$element[7]にNIC名が格納される
+                my @element = split(/\s+/, $_);
+                if ($element[0] eq $netaddr) {
+                        $nic = $element[7];
+                }
+            }
 
             # 特定した NIC に設定されている IC-LAN IP アドレスを取得する
             $command = "$IFCONFIG \"$nic\"";
@@ -771,6 +790,9 @@ sub get_iclan_ipaddr{
             }
 
             if ($results[0] =~ /inet\s(addr:)?(\S+)\s/){
+                if (!is_ipv4_format($2)){
+                    printlog("ERROR", COMMON_MS0052, $2);
+                }
                 push(@{$ipaddr_list{$site[$count]}}, $2);
             }
             else {
@@ -1382,4 +1404,18 @@ sub unlink_pid_file {
     }
 }
 
+sub is_ipv4_format{
+    # 引数に指定されたIPアドレスがIPv4の形式であるかを確認する
+    # IPv4の形式の場合は、戻り値に「0」を返却する
+    # IPv4の形式でない場合は、戻り値に「1」を返却する
+    # チェック対象のIPアドレスは、コマンド実行結果から取得しているため、
+    # 厳密なIPv4の正規表現でIPアドレスであるかは確認しない
+    my ($ipaddr) = @_;
+    if ($ipaddr =~ /^[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+$/){
+        return 1; # OK
+    } else {
+        return 0; # NG
+    }
+}
+
 1;
